@@ -60,7 +60,7 @@ class LSattribute {
    *
    * @retval boolean Retourne true si la création a réussi, false sinon.
    */ 
-  function LSattribute ($name,$config,&$ldapObject) {
+  public function __construct($name, $config, &$ldapObject) {
     $this -> name = $name;
     $this -> config = $config;
     $this -> ldapObject =& $ldapObject;
@@ -90,7 +90,7 @@ class LSattribute {
    * @see LSattr_html::getLabel()
    */ 
 
-  function getLabel() {
+  public function getLabel() {
     if (!$this -> html) {
       LSerror :: addErrorCode('LSattribute_09',array('type' => 'html','name' => $this -> name));
       return;
@@ -105,7 +105,7 @@ class LSattribute {
    *
    * @retval boolean true
    */
-  function loadData($attr_data) {
+  public function loadData($attr_data) {
     if ((!is_array($attr_data))&&(!empty($attr_data))) {
       $attr_data = array($attr_data);
     }
@@ -120,7 +120,7 @@ class LSattribute {
    *
    * @retval boolean true
    */
-  function reloadData($attr_data) {
+  public function reloadData($attr_data) {
     if ((!is_array($attr_data))&&(!empty($attr_data))) {
       $attr_data = array($attr_data);
     }
@@ -139,7 +139,7 @@ class LSattribute {
    *
    * @retval mixed La valeur de l'attribut
    */
-  function getValue() {
+  public function getValue() {
     if ($this -> isUpdate()) {
       return $this -> getUpdateData();
     }
@@ -155,7 +155,7 @@ class LSattribute {
    *
    * @retval mixed La valeur originale de l'attribut
    */
-  function getOldValue() {
+  public function getOldValue() {
     return $this -> data;
   }
   
@@ -166,7 +166,7 @@ class LSattribute {
    *
    * @retval string La valeur d'affichage de l'attribut
    */
-  function getDisplayValue() {
+  public function getDisplayValue() {
     if (!$this -> ldap) {
       LSerror :: addErrorCode('LSattribute_09',array('type' => 'ldap','name' => $this -> name));
       return;
@@ -179,29 +179,21 @@ class LSattribute {
       $data = $this -> ldap -> getDisplayValue($this -> data);
     }
 
-    if (isset($this -> config['onDisplay'])) {
-      if (is_array($this -> config['onDisplay'])) {
-        $result=$data;
-        foreach($this -> config['onDisplay'] as $func) {
-          if (function_exists($func)) {
-            $result=call_user_func($func, $result);
-          }
-          else {
-            LSerror :: addErrorCode('LSattribute_02',array('attr' => $this->name,'func' => $func));
-            return;
-          }
-        }
-        return $result;
-      }
-      else {
-        if (function_exists($this -> config['onDisplay'])) {
-          return $this -> config['onDisplay']($data);
+    $onDisplay = $this -> getConfig('onDisplay');
+    if ($onDisplay) {
+      if (!is_array($onDisplay))
+        $onDisplay = array($onDisplay);
+      $result = $data;
+      foreach($onDisplay as $func) {
+        if (function_exists($func)) {
+          $result = call_user_func($func, $result);
         }
         else {
-          LSerror :: addErrorCode('LSattribute_02',array('attr' => $this->name,'func' => $this -> config['onDisplay']));
+          LSerror :: addErrorCode('LSattribute_02', array('attr' => $this->name, 'func' => $func));
           return;
         }
       }
+      return $result;
     }
     return $data;
   }
@@ -221,8 +213,8 @@ class LSattribute {
    *
    * @retval boolean true si l'ajout a fonctionner ou qu'il n'est pas nécessaire, false sinon
    */
-  function addToForm(&$form,$idForm,&$obj=NULL,$value=NULL) {
-    if(isset($this -> config['form'][$idForm])) {
+  public function addToForm(&$form,$idForm,&$obj=NULL,$value=NULL) {
+    if($this -> getConfig("form.$idForm")) {
       if (!$this -> html) {
         LSerror :: addErrorCode('LSattribute_09',array('type' => 'html','name' => $this -> name));
         return;
@@ -234,13 +226,13 @@ class LSattribute {
         $data = $value;
       }
       else if($this -> data !='') {
-        $data=$this -> getFormVal();
+        $data = $this -> getFormVal();
       }
-      else if (isset($this -> config['default_value'])) {
-        $data=$obj -> getFData($this -> config['default_value']);
+      else if ($this -> getConfig('default_value')) {
+        $data = $obj -> getFData($this -> getConfig('default_value'));
       }
       else {
-        $data=NULL;
+        $data = NULL;
       }
       
       $element = $this -> html -> addToForm($form,$idForm,$data);
@@ -248,35 +240,34 @@ class LSattribute {
         LSerror :: addErrorCode('LSform_06',$this -> name);
       }
 
-      if(isset($this -> config['required']) && $this -> config['required']==1) {
+      if($this -> getConfig('required')) {
         $form -> setRequired($this -> name);
       }
 
-      if (($this -> config['form'][$idForm]==0) || ($this -> myRights() == 'r')) {
+      if ( ($this -> getConfig("form.$idForm")==0) || ($this -> myRights() == 'r') ) {
         $element -> freeze();
       }
       else {
-        if(isset($this -> config['check_data'])) {
-          if(is_array($this -> config['check_data'])) {
-            foreach ($this -> config['check_data'] as $rule => $rule_infos) {
-              if((!$form -> isRuleRegistered($rule))&&($rule!='')) {
-                LSerror :: addErrorCode('LSattribute_03',array('attr' => $this->name,'rule' => $rule));
-                return;
-              }
-              if(!isset($rule_infos['msg'])) {
-                $rule_infos['msg']=getFData(_('The value of field %{label} is invalid.'),$this -> getLabel());
-              }
-              else {
-                $rule_infos['msg']=__($rule_infos['msg']);
-              }
-              if(!isset($rule_infos['params']))
-                $rule_infos['params']=NULL;
-              $form -> addRule($this -> name,$rule,array('msg' => $rule_infos['msg'], 'params' => $rule_infos['params']));
+        $check_data = $this -> getConfig('check_data', array());
+        if(is_array($check_data)) {
+          foreach ($check_data as $rule => $rule_infos) {
+            if((!$form -> isRuleRegistered($rule))&&($rule!='')) {
+              LSerror :: addErrorCode('LSattribute_03',array('attr' => $this->name,'rule' => $rule));
+              return;
             }
+            if(!isset($rule_infos['msg'])) {
+              $rule_infos['msg']=getFData(_('The value of field %{label} is invalid.'),$this -> getLabel());
+            }
+            else {
+              $rule_infos['msg']=__($rule_infos['msg']);
+            }
+            if(!isset($rule_infos['params']))
+              $rule_infos['params']=NULL;
+            $form -> addRule($this -> name,$rule,array('msg' => $rule_infos['msg'], 'params' => $rule_infos['params']));
           }
-          else {
-            LSerror :: addErrorCode('LSattribute_04',$this->name);
-          }
+        }
+        else {
+          LSerror :: addErrorCode('LSattribute_04',$this->name);
         }
       } 
     }
@@ -288,7 +279,7 @@ class LSattribute {
    * 
    * @retval string 'r'/'w'/'n' pour 'read'/'write'/'none'
    **/
-  function myRights() {
+  private function myRights() {
     // cache
     if ($this -> _myRights != NULL) {
       return $this -> _myRights;
@@ -296,29 +287,10 @@ class LSattribute {
     $return='n';
     $whoami = $this -> ldapObject -> whoami();
     foreach($whoami as $who) {
-      switch ($who) {
-        case 'admin':
-          if($this -> config['rights']['admin']=='w') {
-            $return='w';
-            break;
-          }
-          else {
-            $return='r';
-          }
-          break;
-        default:
-          if (!isset($this -> config['rights'][$who])) break;
-          if ($this -> config['rights'][$who] == 'w') {
-            $return='w';
-            break;
-          }
-          else if($this -> config['rights'][$who] == 'r') {
-            $return='r';
-          }
-          break;
-      }
-      if ($return=='w') {
-        break;
+      $right = $this -> getConfig("rights.$who", ($who=='admin'?'r':null));
+      if (in_array($right, array('r', 'w'))) {
+        $return = $right;
+        if ($return == 'w') break;
       }
     }
     $this -> _myRights = $return;
@@ -336,8 +308,8 @@ class LSattribute {
    *
    * @retval boolean true si l'ajout a fonctionner ou qu'il n'est pas nécessaire, false sinon
    */
-  function addToView(&$form) {
-    if((isset($this -> config['view'])) && ($this -> config['view']) && ($this -> myRights() != 'n') ) {
+  public function addToView(&$form) {
+    if ($this -> getConfig('view', false, 'bool') && ($this -> myRights() != 'n') ) {
       if (!$this -> html) {
         LSerror :: addErrorCode('LSattribute_09',array('type' => 'html','name' => $this -> name));
         return;
@@ -369,8 +341,8 @@ class LSattribute {
    *
    * @retval boolean true si la valeur a été rafraichie ou que ce n'est pas nécessaire, false sinon
    */
-  function refreshForm(&$form,$idForm) {
-    if(isset($this -> config['form'][$idForm])&&($this -> myRights()!='n')) {
+  public function refreshForm(&$form,$idForm) {
+    if ($this -> getConfig("form.$idForm") && ($this -> myRights() != 'n')) {
       if (!$this -> html) {
         LSerror :: addErrorCode('LSattribute_09',array('type' => 'html','name' => $this -> name));
         return;
@@ -394,7 +366,7 @@ class LSattribute {
    *
    * @retval string La valeur a afficher dans le formulaire.
    */
-  function getFormVal() {
+  public function getFormVal() {
     $data=$this -> html -> getFormVal($this -> data);
     if ($data==NULL) {
       $data=array();
@@ -414,7 +386,7 @@ class LSattribute {
    *
    * @retval void
    */
-  function setUpdateData($data) {
+  public function setUpdateData($data) {
     if($this -> ldap -> isUpdated($data)) {
       $this -> updateData=$data;
     }
@@ -427,7 +399,7 @@ class LSattribute {
    *
    * @retval boolean true si l'attribut a été validé, false sinon
    */
-  function isValidate() {
+  public function isValidate() {
     return $this -> is_validate;
   }
   
@@ -438,7 +410,7 @@ class LSattribute {
    *
    * @retval void
    */
-  function validate() {
+  public function validate() {
     $this -> is_validate=true;
   }
   
@@ -449,7 +421,7 @@ class LSattribute {
    *
    * @retval boolean true si l'attribut a été mis à jour, false sinon
    */
-  function isUpdate() {
+  public function isUpdate() {
     return ($this -> updateData===false)?false:true;
   }
   
@@ -460,8 +432,8 @@ class LSattribute {
    *
    * @retval boolean true si l'attribut est obligatoire, false sinon
    */
-  function isRequired() {
-    return (isset($this -> config['required'])?(bool)$this -> config['required']:false);
+  public function isRequired() {
+    return $this -> getConfig('required', false, 'bool');
   }
   
   /**
@@ -471,16 +443,15 @@ class LSattribute {
    *
    * @retval boolean true si la valeur de l'attribut peut être générée, false sinon
    */
-  function canBeGenerated() {
+  public function canBeGenerated() {
+    $format = $this -> getConfig('generate_value_format', $this -> getConfig('default_value'));
     return (
-              (function_exists($this -> config['generate_function']))
-              ||
-              (isset($this -> config['generate_value_format']))
+              (function_exists($this -> getConfig('generate_function')))
               ||
               (
-                (is_string($this -> config['default_value']))
+                (is_string($format))
                 &&
-                (strlen($this -> config['default_value'])>0)
+                (strlen($format) > 0)
               )
            );
   }
@@ -492,18 +463,17 @@ class LSattribute {
    *
    * @retval boolean true si la valeur à put être générée, false sinon
    */
-  function generateValue() {
-    $value=false;
-    if (function_exists($this -> config['generate_function'])) {
-      $value=call_user_func_array($this -> config['generate_function'],array(&$this -> ldapObject));
+  public function generateValue() {
+    $value = false;
+    $generate_function = $this -> getConfig('generate_function');
+    $format = $this -> getConfig('generate_value_format', $this -> getConfig('default_value'));
+    if ($generate_function && function_exists($generate_function)) {
+      $value = call_user_func_array($generate_function, array(&$this -> ldapObject));
     }
-    else if (isset($this -> config['generate_value_format'])) {
-      $value = $this -> ldapObject -> getFData($this -> config['generate_value_format']);
+    else if ($format) {
+      $value = $this -> ldapObject -> getFData($format);
     }
-    else if (is_string($this -> config['default_value']) && strlen($this -> config['default_value'])>0) {
-      $value = $this -> ldapObject -> getFData($this -> config['default_value']);
-    }
-    if ($value!==false) {
+    if ($value !== false) {
       if (!empty($value)) {
         if (!is_array($value)) {
           $value=array($value);
@@ -526,7 +496,7 @@ class LSattribute {
    *
    * @retval mixed La valeur de l'attribut pour son enregistrement dans l'annuaire
    */
-  function getUpdateData() {
+  public function getUpdateData() {
     if (!$this -> isUpdate()) {
       return;
     }
@@ -577,7 +547,7 @@ class LSattribute {
    *
    * @retval mixed La configuration de validation de l'attribut
    */
-  function getValidateConfig() {
+  public function getValidateConfig() {
     if (isset($this -> config['validation'])) {
       return $this -> config['validation'];
     }
@@ -591,7 +561,7 @@ class LSattribute {
    *
    * @retval array les noms des attributs dépendants
    */
-  function getDependsAttrs() {
+  public function getDependsAttrs() {
     return (isset($this -> config['dependAttrs'])?$this -> config['dependAttrs']:null);
   }
 
@@ -605,7 +575,7 @@ class LSattribute {
    * 
    * @retval void
    */
-  function addEvent($event,$fct,$params,$class=NULL) {
+  public function addEvent($event,$fct,$params,$class=NULL) {
     $this -> _events[$event][] = array(
       'function'  => $fct,
       'params'    => $params,
@@ -623,7 +593,7 @@ class LSattribute {
    * 
    * @retval void
    */
-  function addObjectEvent($event,&$obj,$meth,$params=NULL) {
+  public function addObjectEvent($event,&$obj,$meth,$params=NULL) {
     $this -> _objectEvents[$event][] = array(
       'obj'  => &$obj,
       'meth'  => $meth,
@@ -638,7 +608,7 @@ class LSattribute {
    * 
    * @retval boolean True si tout c'est bien passé, false sinon
    */
-  function fireEvent($event) {
+  public function fireEvent($event) {
     $return = true;
     if(isset($this -> config[$event])) {
       if (!is_array($this -> config[$event])) {
@@ -721,6 +691,19 @@ class LSattribute {
     
     return $return;
   }
+
+  /**
+   * Return a configuration parameter (or default value)
+   *
+   * @param[] $param	The configuration parameter
+   * @param[] $default	The default value (default : null)
+   * @param[] $cast	Cast resulting value in specific type (default : disabled)
+   *
+   * @retval mixed The configuration parameter value or default value if not set
+   **/
+  public function getConfig($param, $default=null, $cast=null) {
+    return LSconfig :: get($param, $default, $cast, $this -> config);
+  }
   
 }
 
@@ -755,4 +738,3 @@ LSerror :: defineError('LSattribute_09',
   _("LSattribute : The attr_%{type} of the attribute %{name} is not yet defined.")
 );
 
-?>
