@@ -85,7 +85,7 @@ class LSsearch {
    * @param[in] $purgeParams boolean If params in session have to be purged
    * 
    **/
-  function LSsearch($LSobject,$context,$params=null,$purgeParams=false) {
+  public function __construct($LSobject,$context,$params=null,$purgeParams=false) {
     if (!LSsession :: loadLSobject($LSobject)) {
       return;
     }
@@ -106,7 +106,7 @@ class LSsearch {
       }
     }
     else {
-      $this -> purgeParams();
+      $this -> purgeParams($LSobject);
       $this -> loadDefaultParameters();
     }
     
@@ -123,7 +123,7 @@ class LSsearch {
    */
   private function loadConfig() {
     $this -> config = LSconfig::get("LSobjects.".$this -> LSobject.".LSsearch");
-    if (is_array($this -> config['predefinedFilters'])) {
+    if (isset($this -> config['predefinedFilters']) && is_array($this -> config['predefinedFilters'])) {
       foreach($this -> config['predefinedFilters'] as $filter => $label) {
         if(!LSldap::isValidFilter($filter)) {
           LSerror::addErrorCode('LSsearch_15',array('label' => $label, 'filter' => $filter, 'type' => $this -> LSobject));
@@ -179,7 +179,7 @@ class LSsearch {
     
     foreach ($params as $param => $value) {
       if ( !isset($_SESSION['LSsession']['LSsearch'][$this -> LSobject]['params'][$this -> context][$param]) || $_SESSION['LSsession']['LSsearch'][$this -> LSobject]['params'][$this -> context][$param]!=$value) {
-        LSdebug("S: $param => $value");
+        LSdebug("S: $param => ".varDump($value));
         $_SESSION['LSsession']['LSsearch'][$this -> LSobject]['params'][$this -> context][$param]=$value;
       }
     }
@@ -192,10 +192,7 @@ class LSsearch {
    * 
    * @retval void
    */
-  public function purgeParams($LSobject=NULL) {
-    if (is_null($LSobject)) {
-      $LSobject = $this -> LSobject;
-    }
+  public static function purgeParams($LSobject) {
     unset($_SESSION['LSsession']['LSsearch'][$LSobject]['params']);
   }
   
@@ -204,9 +201,7 @@ class LSsearch {
    * 
    * @retval void
    */
-  public function purgeCache($LSobject=NULL) {
-    if (is_null($LSobject))
-      $LSobject = $this -> LSobject;
+  public static function purgeCache($LSobject) {
     unset($_SESSION['LSsession']['LSsearch'][$LSobject]);
   }
   
@@ -372,8 +367,8 @@ class LSsearch {
         }
         else {
           $this -> params['sortBy'] = $params['sortBy'];
-          if (!is_string($params['sortDirection'])) {
-            $this -> params['sortDirection']='ASC';
+          if (!isset($params['sortDirection']) || !is_string($params['sortDirection'])) {
+            $this -> params['sortDirection'] = 'ASC';
           }
         }
       }
@@ -575,7 +570,7 @@ class LSsearch {
    * 
    * @retval mixed Net_LDAP2_Filter on success or False
    */ 
-  function getFilterFromPattern($pattern=NULL) {
+  public function getFilterFromPattern($pattern=NULL) {
     if ($pattern==NULL) {
       $pattern=$this -> params['pattern'];
     }
@@ -752,7 +747,7 @@ class LSsearch {
     }
     
     // Filter
-    $objFilter=LSldapObject::getObjectFilter($this -> LSobject);
+    $objFilter=LSldapObject::_getObjectFilter($this -> LSobject);
     if ($objFilter) {
       if (!is_null($retval['filter'])) {
         $filter=LSldap::combineFilters('and',array($objFilter,$retval['filter']));
@@ -840,7 +835,18 @@ class LSsearch {
     
     $this -> _searchParams = $retval;
   }
-  
+
+  /**
+   * Get search attributes
+   *
+   * @retval array The attributes asked in this search
+   **/
+  public function getAttributes() {
+    if (!$this -> _searchParams)
+      $this -> generateSearchParams();
+    return $this -> _searchParams['attributes'];
+  }
+
   /**
    * Run the search
    *
@@ -1152,7 +1158,7 @@ class LSsearch {
    * 
    * @retval void
    **/
-  function afterUsingResult() {
+  public function afterUsingResult() {
     $this -> addResultToCache();
   }
   
@@ -1161,7 +1167,7 @@ class LSsearch {
    * 
    * @retval boolean True only if user have been redirected
    **/
-  function redirectWhenOnlyOneResult() {
+  public function redirectWhenOnlyOneResult() {
     if ($this -> total == 1 && $this -> result && self::formIsSubmited()) {
       LSsession :: redirect('view.php?LSobject='.$this -> LSobject.'&dn='.urlencode($this -> result['list'][0]['dn']));
     }
@@ -1173,7 +1179,7 @@ class LSsearch {
    * 
    * @retval boolean True on success or false
    **/
-  function doSort() {
+  private function doSort() {
     if (!$this -> sort) {
       LSdebug('doSort : sort is disabled');
       return true;
@@ -1220,7 +1226,7 @@ class LSsearch {
    * 
    * @retval array The Table of id lines of results sorted
    **/
-  function getSortTable() {
+  public function getSortTable() {
     if (isset($this -> result['sort'][$this -> params['sortBy']][$this -> params['sortDirection']])) {
       return $this -> result['sort'][$this -> params['sortBy']][$this -> params['sortDirection']];
     }
@@ -1351,3 +1357,4 @@ _("LSsearch : Error during execution of the custom action %{customAction}.")
 LSerror :: defineError('LSsearch_17',
 _("LSsearch : Invalid search pattern.")
 );
+
