@@ -105,13 +105,7 @@ class LSsession {
     elseif (!file_exists($file)) {
       return;
     }
-    if (defined('LSdebug') && constant('LSdebug')) {
-      return include_once($file);
-    }
-    else {
-      return @include_once($file);
-    }
-    return;
+    return include_once($file);
   }
 
  /**
@@ -348,7 +342,7 @@ class LSsession {
       }
     }
     
-    if (is_null($enconding)) {
+    if (is_null($encoding)) {
       if (isset($_REQUEST['encoding'])) {
         $encoding = $_REQUEST['encoding'];
       }
@@ -537,17 +531,27 @@ class LSsession {
       if (!self :: loadLSobject(self :: $ldapServer['authObjectType'])) {
         return;
       }
+
+      LStemplate :: assign('globalSearch', self :: globalSearch());
       
       if (isset($_GET['LSsession_logout'])) {
+        // Trigger LSauth logout
         LSauth :: logout();
-        session_destroy();
-        
+
+        // Delete temporaries files
         if (is_array($_SESSION['LSsession']['tmp_file'])) {
           self :: $tmp_file = $_SESSION['LSsession']['tmp_file'];
         }
         self :: deleteTmpFile();
+
+        // Destroy local session
         unset($_SESSION['LSsession']);
-        
+        session_destroy();
+
+        // Trigger LSauth after logout
+        LSauth :: afterLogout();
+
+        // Redirect user on home page
         self :: redirect('index.php');
         return;
       }
@@ -630,6 +634,7 @@ class LSsession {
             self :: loadLSaccess();
             self :: loadLSaddonsViewsAccess();
             LStemplate :: assign('LSsession_username',self :: getLSuserObject() -> getDisplayName());
+            LStemplate :: assign('globalSearch', self :: globalSearch());
             $_SESSION['LSsession']=self :: getContextInfos();
             return true;
           }
@@ -1249,9 +1254,11 @@ class LSsession {
     LStemplate :: assign('recoverpasswordform_label_submit',_('Validate'));
     LStemplate :: assign('recoverpasswordform_label_back',_('Back'));
     
+    $recoverpassword_step = 'start';
     $recoverpassword_msg = _('Please fill the identifier field to proceed recovery procedure');
     
     if (isset($recoveryPasswordInfos['recoveryHashMail'])) {
+      $recoverpassword_step = 'token_sent';
       $recoverpassword_msg = getFData(
         _("An email has been sent to  %{mail}. " .
         "Please follow the instructions on it."),
@@ -1260,12 +1267,14 @@ class LSsession {
     }
     
     if (isset($recoveryPasswordInfos['newPasswordMail'])) {
+      $recoverpassword_step = 'new_password_sent';
       $recoverpassword_msg = getFData(
         _("Your new password has been sent to %{mail}. "),
         $recoveryPasswordInfos['newPasswordMail']
       );
     }
     
+    LStemplate :: assign('recoverpassword_step',$recoverpassword_step);
     LStemplate :: assign('recoverpassword_msg',$recoverpassword_msg);
     
     self :: setTemplate('recoverpassword.tpl');
@@ -2252,7 +2261,18 @@ class LSsession {
   public static function cacheSearch() {
     return ( (LSconfig :: get('cacheSearch')) || (self :: $ldapServer['cacheSearch']));
   }
-  
+
+  /**
+   * Return true if global search is enabled
+   *
+   * @author Benjamin Renard <brenard@easter-eggs.com>
+   *
+   * @retval boolean True if global search is enabled, false instead
+   */
+  public static function globalSearch() {
+    return LSconfig :: get('globalSearch', LSconfig :: get('globalSearch', true, 'bool'), 'bool', self :: $ldapServer);
+  }
+
   /**
    * Retourne le label des niveaux pour le serveur ldap courant
    * 
@@ -2587,4 +2607,6 @@ class LSsession {
       call_user_func(self :: $LSaddonsViews[$LSaddon][$viewId]['function']);
     }
   }
+
 }
+
