@@ -29,6 +29,7 @@ $GLOBALS['LSconfig'] = array(
   'cacheLSprofiles' => true,
   'cacheSubDn' => true,
   'cacheSearch' => true,
+  'globalSearch' => true,
   'keepLSsessionActive' => true,
   'ldap_servers' => array (
     array (
@@ -152,6 +153,7 @@ $GLOBALS['LSconfig'] = array(
       ),
       'cacheLSprofiles' => true,
       'cacheSearch' => true,
+      'globalSearch' => false,
       'authObjectTypeAttrPwd' => 'userPassword',
       'recoverPassword' => array(
         'mailAttr' => 'mail',
@@ -206,3 +208,4 @@ $GLOBALS['defaultJSscipts']=array(
 
 // CSS
 $GLOBALS['defaultCSSfiles']=array('../light-blue.css');
+
